@@ -3,15 +3,17 @@ use std::fmt::Write;
 
 use crate::errors::LocItem;
 use pyo3::exceptions::PyValueError;
+use pyo3::ffi;
+use pyo3::ffi::Py_ssize_t;
 use pyo3::prelude::*;
-use pyo3::types::PyDict;
+use pyo3::types::{PyDict, PyList};
 
 use crate::build_tools::py_error_type;
 use crate::input::repr_string;
 
-use super::kinds::ErrorKind;
 use super::line_error::ValLineError;
 use super::location::Location;
+use super::types::ErrorType;
 use super::ValError;
 
 #[pyclass(extends=PyValueError, module="pydantic_core._pydantic_core")]
@@ -45,7 +47,7 @@ impl ValidationError {
         let plural = if count == 1 { "" } else { "s" };
         let title: &str = self.title.extract(py).unwrap();
         let line_errors = pretty_py_line_errors(py, self.line_errors.iter());
-        format!("{} validation error{} for {}\n{}", count, plural, title, line_errors)
+        format!("{count} validation error{plural} for {title}\n{line_errors}")
     }
 
     pub fn omit_error() -> PyErr {
@@ -80,13 +82,24 @@ impl ValidationError {
         self.line_errors.len()
     }
 
-    fn errors(&self, py: Python, include_context: Option<bool>) -> PyResult<PyObject> {
-        Ok(self
-            .line_errors
-            .iter()
-            .map(|e| e.as_dict(py, include_context))
-            .collect::<PyResult<Vec<PyObject>>>()?
-            .into_py(py))
+    fn errors(&self, py: Python, include_context: Option<bool>) -> PyResult<Py<PyList>> {
+        // taken approximately from the pyo3, but modified to return the error during iteration
+        // https://github.com/PyO3/pyo3/blob/a3edbf4fcd595f0e234c87d4705eb600a9779130/src/types/list.rs#L27-L55
+        unsafe {
+            let ptr = ffi::PyList_New(self.line_errors.len() as Py_ssize_t);
+
+            // We create the `Py` pointer here for two reasons:
+            // - panics if the ptr is null
+            // - its Drop cleans up the list if user code or the asserts panic.
+            let list: Py<PyList> = Py::from_owned_ptr(py, ptr);
+
+            for (index, line_error) in (0_isize..).zip(&self.line_errors) {
+                let item = line_error.as_dict(py, include_context)?;
+                ffi::PyList_SET_ITEM(ptr, index, item.into_ptr());
+            }
+
+            Ok(list)
+        }
     }
 
     fn __repr__(&self, py: Python) -> String {
@@ -117,7 +130,7 @@ pub fn pretty_py_line_errors<'a>(py: Python, line_errors_iter: impl Iterator<Ite
     line_errors_iter
         .map(|i| i.pretty(py))
         .collect::<Result<Vec<_>, _>>()
-        .unwrap_or_else(|err| vec![format!("[error formatting line errors: {}]", err)])
+        .unwrap_or_else(|err| vec![format!("[error formatting line errors: {err}]")])
         .join("\n")
 }
 
@@ -126,7 +139,7 @@ pub fn pretty_py_line_errors<'a>(py: Python, line_errors_iter: impl Iterator<Ite
 #[derive(Clone)]
 #[cfg_attr(debug_assertions, derive(Debug))]
 pub struct PyLineError {
-    kind: ErrorKind,
+    error_type: ErrorType,
     location: Location,
     input_value: PyObject,
 }
@@ -134,7 +147,7 @@ pub struct PyLineError {
 impl<'a> IntoPy<PyLineError> for ValLineError<'a> {
     fn into_py(self, py: Python<'_>) -> PyLineError {
         PyLineError {
-            kind: self.kind,
+            error_type: self.error_type,
             location: self.location,
             input_value: self.input_value.to_object(py),
         }
@@ -145,7 +158,7 @@ impl<'a> IntoPy<PyLineError> for ValLineError<'a> {
 impl<'a> IntoPy<ValLineError<'a>> for PyLineError {
     fn into_py(self, _py: Python) -> ValLineError<'a> {
         ValLineError {
-            kind: self.kind,
+            error_type: self.error_type,
             location: self.location,
             input_value: self.input_value.into(),
         }
@@ -155,13 +168,13 @@ impl<'a> IntoPy<ValLineError<'a>> for PyLineError {
 impl PyLineError {
     pub fn as_dict(&self, py: Python, include_context: Option<bool>) -> PyResult<PyObject> {
         let dict = PyDict::new(py);
-        dict.set_item("kind", self.kind.kind())?;
+        dict.set_item("type", self.error_type.type_string())?;
         dict.set_item("loc", self.location.to_object(py))?;
-        dict.set_item("message", self.kind.render_message(py)?)?;
-        dict.set_item("input_value", &self.input_value)?;
+        dict.set_item("msg", self.error_type.render_message(py)?)?;
+        dict.set_item("input", &self.input_value)?;
         if include_context.unwrap_or(true) {
-            if let Some(context) = self.kind.py_dict(py)? {
-                dict.set_item("context", context)?;
+            if let Some(context) = self.error_type.py_dict(py)? {
+                dict.set_item("ctx", context)?;
             }
         }
         Ok(dict.into_py(py))
@@ -171,11 +184,11 @@ impl PyLineError {
         let mut output = String::with_capacity(200);
         write!(output, "{}", self.location)?;
 
-        let message = match self.kind.render_message(py) {
+        let message = match self.error_type.render_message(py) {
             Ok(message) => message,
-            Err(err) => format!("(error rendering message: {})", err),
+            Err(err) => format!("(error rendering message: {err})"),
         };
-        write!(output, "  {} [kind={}", message, self.kind.kind())?;
+        write!(output, "  {message} [type={}", self.error_type.type_string())?;
 
         let input_value = self.input_value.as_ref(py);
         let input_str = match repr_string(input_value) {
@@ -185,7 +198,7 @@ impl PyLineError {
         truncate_input_value!(output, input_str);
 
         if let Ok(type_) = input_value.get_type().name() {
-            write!(output, ", input_type={}", type_)?;
+            write!(output, ", input_type={type_}")?;
         }
         output.push(']');
         Ok(output)
