@@ -7,7 +7,7 @@ use pyo3::types::{PyDict, PyList, PyString};
 use ahash::AHashSet;
 
 use crate::build_tools::{py_err, SchemaDict};
-use crate::errors::{ErrorKind, ValError, ValResult};
+use crate::errors::{ErrorType, ValError, ValResult};
 use crate::input::Input;
 use crate::recursion_guard::{NoHashSet, RecursionGuard};
 
@@ -58,8 +58,8 @@ pub struct LiteralSingleStringValidator {
 
 impl LiteralSingleStringValidator {
     fn new(expected: String) -> Self {
-        let expected_repr = format!("'{}'", expected);
-        let name = format!("literal[{}]", expected_repr);
+        let expected_repr = format!("'{expected}'");
+        let name = format!("literal[{expected_repr}]");
         Self {
             expected,
             expected_repr,
@@ -82,7 +82,7 @@ impl Validator for LiteralSingleStringValidator {
             Ok(input.to_object(py))
         } else {
             Err(ValError::new(
-                ErrorKind::LiteralError {
+                ErrorType::LiteralError {
                     expected: self.expected_repr.clone(),
                 },
                 input,
@@ -105,7 +105,7 @@ impl LiteralSingleIntValidator {
     fn new(expected: i64) -> Self {
         Self {
             expected,
-            name: format!("literal[{}]", expected),
+            name: format!("literal[{expected}]"),
         }
     }
 }
@@ -124,7 +124,7 @@ impl Validator for LiteralSingleIntValidator {
             Ok(input.to_object(py))
         } else {
             Err(ValError::new(
-                ErrorKind::LiteralError {
+                ErrorType::LiteralError {
                     expected: self.expected.to_string(),
                 },
                 input,
@@ -150,13 +150,13 @@ impl LiteralMultipleStringsValidator {
         let mut repr_args = Vec::new();
         for item in expected_list.iter() {
             if let Ok(str) = item.extract() {
-                repr_args.push(format!("'{}'", str));
+                repr_args.push(format!("'{str}'"));
                 expected.insert(str);
             } else {
                 return None;
             }
         }
-        let (expected_repr, name) = expected_repr_name(repr_args);
+        let (expected_repr, name) = expected_repr_name(repr_args, "literal");
         Some(Self {
             expected,
             expected_repr,
@@ -179,7 +179,7 @@ impl Validator for LiteralMultipleStringsValidator {
             Ok(input.to_object(py))
         } else {
             Err(ValError::new(
-                ErrorKind::LiteralError {
+                ErrorType::LiteralError {
                     expected: self.expected_repr.clone(),
                 },
                 input,
@@ -211,7 +211,7 @@ impl LiteralMultipleIntsValidator {
                 return None;
             }
         }
-        let (expected_repr, name) = expected_repr_name(repr_args);
+        let (expected_repr, name) = expected_repr_name(repr_args, "literal");
         Some(Self {
             expected,
             expected_repr,
@@ -234,7 +234,7 @@ impl Validator for LiteralMultipleIntsValidator {
             Ok(input.to_object(py))
         } else {
             Err(ValError::new(
-                ErrorKind::LiteralError {
+                ErrorType::LiteralError {
                     expected: self.expected_repr.clone(),
                 },
                 input,
@@ -273,7 +273,7 @@ impl LiteralGeneralValidator {
                 expected_py.append(item)?;
             }
         }
-        let (expected_repr, name) = expected_repr_name(repr_args);
+        let (expected_repr, name) = expected_repr_name(repr_args, "literal");
         Ok(Self {
             expected_int,
             expected_str,
@@ -316,7 +316,7 @@ impl Validator for LiteralGeneralValidator {
         }
 
         Err(ValError::new(
-            ErrorKind::LiteralError {
+            ErrorType::LiteralError {
                 expected: self.expected_repr.clone(),
             },
             input,
@@ -328,14 +328,14 @@ impl Validator for LiteralGeneralValidator {
     }
 }
 
-fn expected_repr_name(mut repr_args: Vec<String>) -> (String, String) {
-    let name = format!("literal[{}]", repr_args.join(","));
+pub fn expected_repr_name(mut repr_args: Vec<String>, base_name: &'static str) -> (String, String) {
+    let name = format!("{base_name}[{}]", repr_args.join(","));
     // unwrap is okay since we check the length in build at the top of this file
     let last_repr = repr_args.pop().unwrap();
     let repr = if repr_args.is_empty() {
         last_repr
     } else {
-        format!("{} or {}", repr_args.join(", "), last_repr)
+        format!("{} or {last_repr}", repr_args.join(", "))
     };
     (repr, name)
 }
