@@ -8,7 +8,7 @@ use pyo3::types::{PyDict, PyList, PyString};
 use ahash::AHashMap;
 
 use crate::build_tools::{is_strict, schema_or_config, SchemaDict};
-use crate::errors::{ErrorKind, ValError, ValLineError, ValResult};
+use crate::errors::{ErrorType, ValError, ValLineError, ValResult};
 use crate::input::{GenericMapping, Input};
 use crate::lookup_key::LookupKey;
 use crate::questions::Question;
@@ -46,7 +46,7 @@ impl BuildValidator for UnionValidator {
             choices,
             custom_error: CustomError::build(schema)?,
             strict: is_strict(schema, config)?,
-            name: format!("{}[{}]", Self::EXPECTED_TYPE, descr),
+            name: format!("{}[{descr}]", Self::EXPECTED_TYPE),
         }
         .into())
     }
@@ -217,10 +217,10 @@ impl BuildValidator for TaggedUnionValidator {
             let validator = build_validator(value, config, build_context)?;
             if first {
                 first = false;
-                write!(tags_repr, "'{}'", tag).unwrap();
+                write!(tags_repr, "'{tag}'").unwrap();
                 descr.push_str(validator.get_name());
             } else {
-                write!(tags_repr, ", '{}'", tag).unwrap();
+                write!(tags_repr, ", '{tag}'").unwrap();
                 // no spaces in get_name() output to make loc easy to read
                 write!(descr, ",{}", validator.get_name()).unwrap();
             }
@@ -238,7 +238,7 @@ impl BuildValidator for TaggedUnionValidator {
             custom_error: CustomError::build(schema)?,
             tags_repr,
             discriminator_repr,
-            name: format!("{}[{}]", Self::EXPECTED_TYPE, descr),
+            name: format!("{}[{descr}]", Self::EXPECTED_TYPE),
         }
         .into())
     }
@@ -378,7 +378,7 @@ impl TaggedUnionValidator {
             match self.custom_error {
                 Some(ref custom_error) => Err(custom_error.as_val_error(input)),
                 None => Err(ValError::new(
-                    ErrorKind::UnionTagInvalid {
+                    ErrorType::UnionTagInvalid {
                         discriminator: self.discriminator_repr.clone(),
                         tag: tag.to_string(),
                         expected_tags: self.tags_repr.clone(),
@@ -393,7 +393,7 @@ impl TaggedUnionValidator {
         match self.custom_error {
             Some(ref custom_error) => custom_error.as_val_error(input),
             None => ValError::new(
-                ErrorKind::UnionTagNotFound {
+                ErrorType::UnionTagNotFound {
                     discriminator: self.discriminator_repr.clone(),
                 },
                 input,
